"""
Converts .csv files to .shape files
"""

from fiona.crs import from_epsg
import fiona
from shapely.geometry import Point, mapping
from fiona import collection
import pandas as pd
import os

def sites_csv_to_shp(input_csv='.\data\interim\sites.csv', output_shp='.\data\interim\sites.shp'):
    """
    Converts our dataframe of sites to .shp to load in QGis
    :param input_csv:
    :param output_shp:
    :return:
    """
    df_sites = pd.read_csv(input_csv, index_col=[0])

    schema = {
        'geometry': 'Point',
        'properties': {
            'beach': 'str',
            'site_id': 'str'
        }
    }
    with fiona.open(output_shp, 'w', crs=from_epsg(4326), driver='ESRI Shapefile', schema=schema) as output:
        for index, row in df_sites.iterrows():
            point = Point(row['lon'], row['lat'])
            prop = {
                'beach': row['beach'],
                'site_id': index,
            }
            output.write({'geometry': mapping(point), 'properties': prop})

if __name__ == '__main__':
    sites_csv_to_shp()
